.. currentmodule:: sardana.macroserver.msparameter

:mod:`~sardana.macroserver.msparameter`
===========================================

.. automodule:: sardana.macroserver.msparameter

.. rubric:: Functions

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`ParamType`

ParamType
-----------

.. autoclass:: ParamType
    :show-inheritance:
